==> ejc-proequipmentcorp-impl-3.0.0-20221227.095802-272-sources.jar: com/ejianc/business/proequipmentcorpout/contract/bean/OutRentChangeOtherDetailedEntity.java <==
package com.ejianc.business.proequipmentcorpout.contract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁合同变更其它费用
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outequipmentcorp_rent_change_other_detailed")
public class OutRentChangeOtherDetailedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项目名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="num")
    private Integer num; // 数量
    @TableField(value="tax_amount")
    private BigDecimal taxAmount; // 含税金额
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="not_tax_price")
    private BigDecimal notTaxPrice; // 单价无税
    @TableField(value="not_tax_amount")
    private BigDecimal notTaxAmount; // 金额(无税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="change_id")
    private Long changeId; // 变更id
    @TableField(value="src_tbl_id")
    private Long srcTblId; // 来源子表主键
    @TableField(value="before_price")
    private BigDecimal beforePrice; // 变更前单价
    @TableField(value="before_num")
    private Integer beforeNum; // 变更前数量
    @TableField(value="before_tax_amount")
    private BigDecimal beforeTaxAmount; // 变更前含税金额
    @TableField(value="before_tax")
    private BigDecimal beforeTax; // 变更前税额
    @TableField(value="before_not_tax_price")
    private BigDecimal beforeNotTaxPrice; // 变更前单价无税
    @TableField(value="before_not_tax_amount")
    private BigDecimal beforeNotTaxAmount; // 变更前金额(无税)
    @TableField(value="contrast_flag")
    private Boolean contrastFlag;
    @TableField(value="tax_money")
    private BigDecimal taxMoney; // 税额
    @TableField(value="change_type")
    private String changeType; // 变更类型

    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public BigDecimal getTaxMoney() {
        return taxMoney;
    }

    public void setTaxMoney(BigDecimal taxMoney) {
        this.taxMoney = taxMoney;
    }



    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public BigDecimal getTaxAmount() {
        return taxAmount;
    }

    public void setTaxAmount(BigDecimal taxAmount) {
        this.taxAmount = taxAmount;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getNotTaxPrice() {
        return notTaxPrice;
    }

    public void setNotTaxPrice(BigDecimal notTaxPrice) {
        this.notTaxPrice = notTaxPrice;
    }
    public BigDecimal getNotTaxAmount() {
        return notTaxAmount;
    }

    public void setNotTaxAmount(BigDecimal notTaxAmount) {
        this.notTaxAmount = notTaxAmount;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }
    public BigDecimal getBeforePrice() {
        return beforePrice;
    }

    public void setBeforePrice(BigDecimal beforePrice) {
        this.beforePrice = beforePrice;
    }

    public Integer getBeforeNum() {
        return beforeNum;
    }

    public void setBeforeNum(Integer beforeNum) {
        this.beforeNum = beforeNum;
    }

    public BigDecimal getBeforeTaxAmount() {
        return beforeTaxAmount;
    }

    public void setBeforeTaxAmount(BigDecimal beforeTaxAmount) {
        this.beforeTaxAmount = beforeTaxAmount;
    }
    public BigDecimal getBeforeTax() {
        return beforeTax;
    }

    public void setBeforeTax(BigDecimal beforeTax) {
        this.beforeTax = beforeTax;
    }
    public BigDecimal getBeforeNotTaxPrice() {
        return beforeNotTaxPrice;
    }

    public void setBeforeNotTaxPrice(BigDecimal beforeNotTaxPrice) {
        this.beforeNotTaxPrice = beforeNotTaxPrice;
    }
    public BigDecimal getBeforeNotTaxAmount() {
        return beforeNotTaxAmount;
    }

    public void setBeforeNotTaxAmount(BigDecimal beforeNotTaxAmount) {
        this.beforeNotTaxAmount = beforeNotTaxAmount;
    }

    public Boolean getContrastFlag() {
        return contrastFlag;
    }

    public void setContrastFlag(Boolean contrastFlag) {
        this.contrastFlag = contrastFlag;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20251013.062057-516-sources.jar: com/ejianc/business/proequipmentcorpout/contract/bean/OutRentChangeOtherDetailedEntity.java <==
package com.ejianc.business.proequipmentcorpout.contract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁合同变更其它费用
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outequipmentcorp_rent_change_other_detailed")
public class OutRentChangeOtherDetailedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项目名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="tax_amount")
    private BigDecimal taxAmount; // 含税金额
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="not_tax_price")
    private BigDecimal notTaxPrice; // 单价无税
    @TableField(value="not_tax_amount")
    private BigDecimal notTaxAmount; // 金额(无税)
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="change_id")
    private Long changeId; // 变更id
    @TableField(value="src_tbl_id")
    private Long srcTblId; // 来源子表主键
    @TableField(value="before_price")
    private BigDecimal beforePrice; // 变更前单价
    @TableField(value="before_num")
    private BigDecimal beforeNum; // 变更前数量
    @TableField(value="before_tax_amount")
    private BigDecimal beforeTaxAmount; // 变更前含税金额
    @TableField(value="before_tax")
    private BigDecimal beforeTax; // 变更前税额
    @TableField(value="before_not_tax_price")
    private BigDecimal beforeNotTaxPrice; // 变更前单价无税
    @TableField(value="before_not_tax_amount")
    private BigDecimal beforeNotTaxAmount; // 变更前金额(无税)
    @TableField(value="contrast_flag")
    private Boolean contrastFlag;
    @TableField(value="tax_money")
    private BigDecimal taxMoney; // 税额
    @TableField(value="change_type")
    private String changeType; // 变更类型

    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public BigDecimal getTaxMoney() {
        return taxMoney;
    }

    public void setTaxMoney(BigDecimal taxMoney) {
        this.taxMoney = taxMoney;
    }



    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getTaxAmount() {
        return taxAmount;
    }

    public void setTaxAmount(BigDecimal taxAmount) {
        this.taxAmount = taxAmount;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getNotTaxPrice() {
        return notTaxPrice;
    }

    public void setNotTaxPrice(BigDecimal notTaxPrice) {
        this.notTaxPrice = notTaxPrice;
    }
    public BigDecimal getNotTaxAmount() {
        return notTaxAmount;
    }

    public void setNotTaxAmount(BigDecimal notTaxAmount) {
        this.notTaxAmount = notTaxAmount;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }
    public BigDecimal getBeforePrice() {
        return beforePrice;
    }

    public void setBeforePrice(BigDecimal beforePrice) {
        this.beforePrice = beforePrice;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getBeforeNum() {
        return beforeNum;
    }

    public void setBeforeNum(BigDecimal beforeNum) {
        this.beforeNum = beforeNum;
    }

    public BigDecimal getBeforeTaxAmount() {
        return beforeTaxAmount;
    }

    public void setBeforeTaxAmount(BigDecimal beforeTaxAmount) {
        this.beforeTaxAmount = beforeTaxAmount;
    }
    public BigDecimal getBeforeTax() {
        return beforeTax;
    }

    public void setBeforeTax(BigDecimal beforeTax) {
        this.beforeTax = beforeTax;
    }
    public BigDecimal getBeforeNotTaxPrice() {
        return beforeNotTaxPrice;
    }

    public void setBeforeNotTaxPrice(BigDecimal beforeNotTaxPrice) {
        this.beforeNotTaxPrice = beforeNotTaxPrice;
    }
    public BigDecimal getBeforeNotTaxAmount() {
        return beforeNotTaxAmount;
    }

    public void setBeforeNotTaxAmount(BigDecimal beforeNotTaxAmount) {
        this.beforeNotTaxAmount = beforeNotTaxAmount;
    }

    public Boolean getContrastFlag() {
        return contrastFlag;
    }

    public void setContrastFlag(Boolean contrastFlag) {
        this.contrastFlag = contrastFlag;
    }
}
